.pragma library

var cViaviColorLogoPurple = "#500778"
var cViaviColorWhite = "#FFFFFF"
var cViaviColorLightGray1 = "#F2F2F2"
var cViaviColorLightGray2 = "#DBDBDB"
var cViaviColorLightGray3 = "#C6C6C6"
var cViaviColorMediumGray = "#999999"
var cViaviColorLightBlue = "#00A9E0"
var cViaviColorMediumBlue = "#426DA9"
var cViaviColorDarkBlue = "#0040A6"
var cViaviColorBlueGreen = "#00B0A2"
var cViaviColorGreen = "#2CB34A"
var cViaviColorLightGreen = "#9ACD32"
var cViaviColorRed = "#D50032"
var cViaviColorYellow = "#FFB500"
var cViaviColorOrange = "#E87722"
var cViaviColorBurgundy = "#8A1b61"
var cViaviColorGray = "#5A5A5A"
var cViaviColorGray2 = "#414141"
var cViaviColorDarkGray = "#333333"
var cViaviColorBlack = "#333333"
var cViaviRealBlack = "#000000"

var cViaviColorSlmPurple = "#9D70C1"

